Module render

Module render 

Per-entity formatters for file details, module info, and summary file details.

Enums

FormatterError

Functions

format_file_details
Format file-level semantic analysis results.
format_file_details_summary
Format a compact summary of file details for large FileDetails output.
format_module_info
Format a ModuleInfo into a compact single-block string.