Module csharp

Module csharp 

Constants

CALL_QUERY
Tree-sitter query for extracting C# method invocations.
DEFUSE_QUERY
Tree-sitter query for extracting definition and use sites.
ELEMENT_QUERY
Tree-sitter query for extracting C# elements (methods, constructors, classes, interfaces, records, structs, and enums).
IMPORT_QUERY
Tree-sitter query for extracting C# using directives.
REFERENCE_QUERY
Tree-sitter query for extracting C# type references (base types, generic args).

Functions

extract_function_name
Extract function name from a C# method or constructor declaration.
extract_inheritance
Extract base class and interface names from a C# class, interface, or record node.
find_method_for_receiver
Return the method or constructor name when node is a method_declaration or constructor_declaration that is nested inside a class, interface, or record body.
find_receiver_type
Find receiver type (enclosing class/struct/interface/record/enum) for a C# method.