pub struct StructuralGraph {
pub graph: DiGraph<Node, Edge>,
/* private fields */
}Fields
graph: DiGraph<Node, Edge>Implementations
Sourceimpl StructuralGraph
impl StructuralGraph
pub fn from_graph(graph: DiGraph<Node, Edge>) -> Self
pub fn build_from_analysis(entries: &[FileAnalysisOutput]) -> Self
pub fn bfs_blast_radius(&self, symbol: &str, depth: usize) -> Vec<NodeIndex>
Sourcepub fn blast_radius_subgraph(
&self,
symbol: &str,
depth: usize,
) -> (Vec<NodeIndex>, Vec<(NodeIndex, NodeIndex, Edge)>)
pub fn blast_radius_subgraph( &self, symbol: &str, depth: usize, ) -> (Vec<NodeIndex>, Vec<(NodeIndex, NodeIndex, Edge)>)
Blast-radius subgraph including both nodes and edges.
Returns a tuple of (nodes, edges) where:
- nodes: Vec
with the start symbol first, followed by all discovered nodes in BFS order - edges: Vec<(NodeIndex, NodeIndex, Edge)> containing every edge whose source and target are both in the visited set (not just edges walked by the BFS tree), allowing clients to fully reconstruct the subgraph’s connectivity
If the symbol is not found, returns (vec![], vec![]).