Extract the name of a function or subroutine node.
Both subroutine_statement and function_statement expose a named field
called name. Return the identifier text if present.
Find the method name for a subroutine/function defined inside a module.
Returns the function/subroutine identifier if the node is enclosed by a module.